@@ -194,7 +194,53 @@ def VacancyAnalysis():
         )
         #print(out.head())
 
-            
+
+
+
+        data_path = Path("outputs/json/training_graph.json")  # ajustá el path si corresponde
+        cfg = ModelConfig(artifacts_dir="artifacts_keras")
+
+        clf = VacancyClassifierKeras(cfg)
+        df = clf.load_json(data_path)
+
+        # 2) Preparar arrays
+        X, y = clf.prepare_arrays(df)
+
+        # 3) Split + escalado
+        X_train, X_val, X_test, y_train, y_val, y_test = clf.split_and_scale(X, y)
+
+        # 4) Construir y entrenar
+        clf.build_model(input_dim=X_train.shape[1])
+        clf.fit(X_train, y_train, X_val, y_val, verbose=1)
+
+        # 5) Evaluar
+        metrics = clf.evaluate(X_test, y_test)
+        print("\n== Métricas de test ==")
+        for k, v in metrics.items():
+            print(f"{k}: {v:.4f}")
+
+        # 6) Inferencia (ejemplo con la primera fila original del DataFrame)
+        #    OJO: acá usamos los valores NO escalados (la clase escala internamente).
+        sample = {k: float(df.iloc[0][k]) for k in clf.feature_order}
+        pred, probs = clf.predict_one(sample)
+        print(f"\nPredicción de vacancias (1..C): {pred}")
+        print("Probabilidades:", probs)
+# ... (ya corriste exporter.export(), clf.classify_csv(...), etc.)
+
+        try:
+            keras_out_csv = "outputs/csv/finger_data_predicho_keras.csv"
+            run_keras_classifier(
+                train_json_path="outputs/json/training_graph.json",
+                input_csv="outputs/csv/finger_data_clasificado.csv",
+                output_csv=keras_out_csv,
+                artifacts_dir="outputs/keras_artifacts",
+                retrain=False,  # poné True si querés reentrenar siempre
+                verbose=0
+            )
+        except Exception as e:
+            print(f"[KERAS] Aviso: no se pudo entrenar/predicir: {e}")
+
+                    
 
 if __name__ == "__main__":
     VacancyAnalysis()
