@@ -96,6 +96,7 @@ def render_dump_to(plotter: QtInteractor, fig: plt.Figure, dump_path: str):
     if cluster_vals is not None and cluster_vals.shape[0] == positions.shape[0]:
         unique_clusters = np.unique(cluster_vals)
         map_idx = {val: i for i, val in enumerate(unique_clusters)}
+        # vectorizado seguro
         cluster_idx = np.vectorize(map_idx.get, otypes=[int])(cluster_vals)
 
     # === Vista 3D ===
@@ -112,7 +113,7 @@ def render_dump_to(plotter: QtInteractor, fig: plt.Figure, dump_path: str):
             render_points_as_spheres=True,
             point_size=8,
             cmap="tab20",
-            show_scalar_bar=False,
+            show_scalar_bar=False,   # oculto barra para muchos clústeres
         )
     else:
         plotter.add_mesh(
@@ -134,6 +135,7 @@ def render_dump_to(plotter: QtInteractor, fig: plt.Figure, dump_path: str):
         ax.plot([x0, x1], [y0, y1], '-', linewidth=1)
 
     if cluster_idx is not None:
+        # Paleta consistente con PyVista
         ax.scatter(
             positions[:, 0], positions[:, 1], s=10,
             c=cluster_idx, cmap="tab20",
@@ -200,148 +202,83 @@ class DumpViewerWidget(QWidget):
         self.path_edit.setText(p)
         render_dump_to(self.plotter, self.fig, p)
 
+
 class KeyAreaSeqWidget(QWidget):
-    """Panel de métricas (results.csv) SIN selector key_file_{i}."""
-    def __init__(self, parent=None):
+    """Viewer para outputs/dump/key_area_{i}.dump con controles de índice."""
+    def __init__(self, parent=None, pattern: str = "outputs/dump/key_area_{i}.dump"):
         super().__init__(parent)
-        self._results_df = None  # cache df results
+        self.pattern = pattern
 
-        # --- Panel de distribución de poros (results.csv) ---
-        dist_panel = QWidget()
-        dist_l = QVBoxLayout(dist_panel)
+        top = QWidget()
+        top_l = QHBoxLayout(top)
+        self.idx = QSpinBox()
+        self.idx.setRange(0, 1_000_000)
+        self.btn_prev = QPushButton("◀ Prev")
+        self.btn_next = QPushButton("Next ▶")
+        self.btn_load = QPushButton("Load")
+        self.path_lbl = QLineEdit()
+        self.path_lbl.setReadOnly(True)
 
-        # Acciones / ruta
-        row = QWidget()
-        row_l = QHBoxLayout(row)
-        self.results_btn = QPushButton("Cargar results.csv")
-        self.results_path = QLineEdit(str(Path.cwd() / "outputs" / "csv" / "results.csv"))
-        self.results_path.setReadOnly(True)
-        row_l.addWidget(self.results_btn)
-        row_l.addWidget(self.results_path, 1)
-        dist_l.addWidget(row)
+        top_l.addWidget(QLabel("key_area_{i}.dump   i="))
+        top_l.addWidget(self.idx)
+        top_l.addWidget(self.btn_prev)
+        top_l.addWidget(self.btn_next)
+        top_l.addWidget(self.btn_load)
+        top_l.addWidget(QLabel("Archivo:"))
+        top_l.addWidget(self.path_lbl, 1)
 
-        # Tabla de vista (primeras filas o todo si querés)
-        self.table_results = QTableWidget()
-        self.table_results.setMinimumHeight(160)
-        dist_l.addWidget(QLabel("Vista de resultados (archivo, surface_area, filled_volume, predicted_vacancy):"))
-        dist_l.addWidget(self.table_results)
+        center = QWidget()
+        center_l = QVBoxLayout(center)
+        self.plotter = QtInteractor(center)
+        center_l.addWidget(self.plotter)
+        self.fig = plt.figure(figsize=(4, 4))
+        self.canvas = FigureCanvas(self.fig)
+        center_l.addWidget(self.canvas)
 
-        # Canvas para gráficos (2x2)
-        self.fig_dist = plt.figure(figsize=(6, 5))
-        self.canvas_dist = FigureCanvas(self.fig_dist)
-        dist_l.addWidget(self.canvas_dist)
-
-        # Conexión
-        self.results_btn.clicked.connect(self.load_results_csv)
-
-        # --- Layout raíz de la pestaña (solo el panel de métricas) ---
         root_l = QVBoxLayout(self)
-        root_l.addWidget(dist_panel)
+        root_l.addWidget(top)
+        root_l.addWidget(center, 1)
 
-    # ----------- normalizador de columnas -----------
-    def _normalize_results_df(self, df: pd.DataFrame) -> pd.DataFrame:
-        # normaliza nombres
-        normmap = {c.lower().strip(): c for c in df.columns}
-        def getcol(*cands):
-            for c in cands:
-                if c in normmap:
-                    return normmap[c]
-            return None
+        self.btn_prev.clicked.connect(lambda: self._step(-1))
+        self.btn_next.clicked.connect(lambda: self._step(+1))
+        self.btn_load.clicked.connect(self._load_idx)
 
-        col_archivo = getcol("archivo", "file", "path")
-        col_area    = getcol("surface_area", "area", "surfacearea")
-        col_vol     = getcol("filled_volume", "volume", "filledvolume")
-        col_vac     = getcol("predicted_vacancy", "vacancy", "vacancys", "vacancys_est", "predicted")
+        self._auto_seed_index()
 
-        missing = []
-        if col_archivo is None: missing.append("archivo")
-        if col_area    is None: missing.append("surface_area")
-        if col_vol     is None: missing.append("filled_volume")
-        if col_vac     is None: missing.append("predicted_vacancy")
-        if missing:
-            raise ValueError("Faltan columnas requeridas: " + ", ".join(missing) +
-                             f"\nColumnas disponibles: {list(df.columns)}")
+    def _pattern_path(self, i: int) -> str:
+        return self.pattern.format(i=i)
 
-        out = df.rename(columns={
-            col_archivo: "archivo",
-            col_area: "surface_area",
-            col_vol: "filled_volume",
-            col_vac: "predicted_vacancy"
-        }).copy()
-
-        for c in ("surface_area", "filled_volume", "predicted_vacancy"):
-            out[c] = pd.to_numeric(out[c], errors="coerce")
-
-        out = out.dropna(subset=["surface_area", "filled_volume", "predicted_vacancy"])
-        return out
-
-    # ----------- carga y ploteo -----------
-    def load_results_csv(self):
-        try:
-            path = Path(self.results_path.text().strip())
-            if not path.exists():
-                # fallback por si el usuario lo movió
-                path = Path.cwd() / "outputs" / "csv" / "results.csv"
-                self.results_path.setText(str(path))
-            if not path.exists():
-                QMessageBox.warning(self, "No existe", f"No se encontró:\n{path.as_posix()}")
+    def _auto_seed_index(self):
+        for i in range(0, 10000):
+            if Path(self._pattern_path(i)).exists():
+                self.idx.setValue(i)
+                self._load_idx()
                 return
+        self.path_lbl.setText("(no encontrado)")
 
-            df = pd.read_csv(path)
-            df = self._normalize_results_df(df)
-            self._results_df = df
-
-            # ---- Poblar tabla con columnas clave ----
-            cols = ["archivo", "surface_area", "filled_volume", "predicted_vacancy"]
-            self.table_results.clear()
-            self.table_results.setColumnCount(len(cols))
-            self.table_results.setRowCount(len(df))
-            self.table_results.setHorizontalHeaderLabels(cols)
-            for i in range(len(df)):
-                for j, col in enumerate(cols):
-                    self.table_results.setItem(i, j, QTableWidgetItem(str(df.iat[i, df.columns.get_loc(col)])))
-            self.table_results.resizeColumnsToContents()
-
-            # ---- Dibujar gráficos (2x2) ----
-            self.fig_dist.clf()
-            axs = self.fig_dist.subplots(2, 2)
-
-            # Hist surface_area
-            axs[0, 0].hist(df["surface_area"].values, bins="auto")
-            axs[0, 0].set_title("Distribución: surface_area")
-            axs[0, 0].set_xlabel("surface_area"); axs[0, 0].set_ylabel("Frecuencia")
-
-            # Hist filled_volume
-            axs[0, 1].hist(df["filled_volume"].values, bins="auto")
-            axs[0, 1].set_title("Distribución: filled_volume")
-            axs[0, 1].set_xlabel("filled_volume"); axs[0, 1].set_ylabel("Frecuencia")
-
-            # Conteo predicted_vacancy (redondeado a entero)
-            vac_counts = df["predicted_vacancy"].round(0).astype(int).value_counts().sort_index()
-            axs[1, 0].bar(vac_counts.index.astype(str), vac_counts.values)
-            axs[1, 0].set_title("Conteo: predicted_vacancy")
-            axs[1, 0].set_xlabel("predicted_vacancy"); axs[1, 0].set_ylabel("Cantidad de poros")
-
-            # Scatter SA vs FV (tamaño ~ vacancias)
-            s = df["predicted_vacancy"].values
-            scale = 15 / (np.nanpercentile(s, 90) + 1e-9)
-            size = 10 + scale * s
-            axs[1, 1].scatter(df["surface_area"].values, df["filled_volume"].values, s=size)
-            axs[1, 1].set_title("surface_area vs filled_volume (size ~ vacancias)")
-            axs[1, 1].set_xlabel("surface_area"); axs[1, 1].set_ylabel("filled_volume")
-
-            self.fig_dist.tight_layout()
-            self.canvas_dist.draw()
+    def _step(self, delta: int):
+        new_i = max(0, self.idx.value() + delta)
+        self.idx.setValue(new_i)
+        self._load_idx()
 
+    def _load_idx(self):
+        p = self._pattern_path(self.idx.value())
+        self.path_lbl.setText(p)
+        if not Path(p).exists():
+            QMessageBox.warning(self, "No existe", f"No se encontró:\n{p}")
+            return
+        try:
+            render_dump_to(self.plotter, self.fig, p)
         except Exception as e:
-            QMessageBox.critical(self, "Error al cargar results.csv", str(e))
+            QMessageBox.critical(self, "Error", str(e))
+
 
 # ---------- Ventana principal ----------
 class SettingsWindow(QMainWindow):
     def __init__(self):
         super().__init__()
         self.showMaximized()
-        self.setWindowTitle("VacancyFinder-SiMAF   0.4.1.4")
+        self.setWindowTitle("VacancyFinder-SiMAF   0.3.9.4")
 
         self.params = load_params()
         cfg = self.params.setdefault('CONFIG', [{}])[0]
@@ -429,15 +366,16 @@ class SettingsWindow(QMainWindow):
         # Botones
         btn_save = QPushButton("Save Settings"); btn_save.clicked.connect(self.save_settings_and_notify)
         btn_run = QPushButton("Run VacancyAnalysis"); btn_run.clicked.connect(self.run_vacancy_analysis)
-        btn_total = QPushButton("Total Vacancies"); btn_total.clicked.connect(self.show_total_vacancies)
+        btn_total = QPushButton("Total Vacancies"); btn_total.clicked.connect(self.show_total_vacancies)  # ⬅️ nuevo
 
         hb = QHBoxLayout(); hb.addWidget(btn_save); hb.addWidget(btn_run)
+
         form_layout.addRow(hb)
 
         hb = QHBoxLayout()
         hb.addWidget(btn_save)
         hb.addWidget(btn_run)
-        hb.addWidget(btn_total)
+        hb.addWidget(btn_total)  # ⬅️ nuevo
         form_layout.addRow(hb)
 
         # Panel izquierdo (controles)
@@ -448,7 +386,7 @@ class SettingsWindow(QMainWindow):
         # Panel derecho con pestañas (Main / Viewer 1 / Key Areas)
         tabs = QTabWidget()
 
-        # --- Tab Main ---
+        # --- Tab Main (tu viewer original) ---
         main_tab = QWidget(); main_layout = QVBoxLayout(main_tab)
         self.plotter = QtInteractor(main_tab); main_layout.addWidget(self.plotter)
         self.fig = plt.figure(figsize=(4, 4)); self.canvas = FigureCanvas(self.fig); main_layout.addWidget(self.canvas)
@@ -458,14 +396,10 @@ class SettingsWindow(QMainWindow):
         # --- Tab Viewer 1 ---
         self.viewer1 = DumpViewerWidget()
         tabs.addTab(self.viewer1, "Viewer 1")
-        # --- Tab Key Areas (ahora con distribución) ---
-        self.viewer2 = KeyAreaSeqWidget()
-        tabs.addTab(self.viewer2, "Metrics")
-        # --- Tab Key Areas (original) ---
 
-        # --- Tab Key Areas (solo 3D/2D, sin CSV ni histogramas) ---
-        self.viewer3d = KeyArea3DOnlyWidget()
-        tabs.addTab(self.viewer3d, "Key Areas")
+        # --- Tab Key Areas ---
+        self.viewer2 = KeyAreaSeqWidget()
+        tabs.addTab(self.viewer2, "Key Areas")
 
         # Layout principal
         main = QWidget(); hl = QHBoxLayout(main); hl.addWidget(scroll); hl.addWidget(tabs, 1)
@@ -517,7 +451,6 @@ class SettingsWindow(QMainWindow):
             widget = getattr(self, f"spin_{key}".replace(' ', '_'))
             cfg[key] = widget.value()
         return save_params(self.params)
-
     def show_total_vacancies(self):
         """Abre una ventana con el total de vacancias de outputs/csv/results.csv."""
         try:
@@ -528,6 +461,8 @@ class SettingsWindow(QMainWindow):
                 return
 
             df = pd.read_csv(path)
+
+            # columnas candidatas donde puede estar el número de vacancias por fila
             candidates = ["predicted_vacancy", "vacancys_est", "vacancys", "predicted", "vacancy"]
             col = next((c for c in candidates if c in df.columns), None)
             if col is None:
@@ -540,11 +475,14 @@ class SettingsWindow(QMainWindow):
 
             vals = pd.to_numeric(df[col], errors='coerce').fillna(0.0)
             total = float(vals.sum())
-            total_int = int(np.ceil(total))  # redondeo hacia arriba
+            total_int = int(np.ceil(total))  # redondeo hacia arriba por si hay decimales
 
+            # Mensaje bonito
             msg = QMessageBox(self)
             msg.setWindowTitle("Total de vacancias")
-            msg.setText(f"<h2 style='margin:0'>Total de vacancias: {total_int}</h2>")
+            msg.setText(
+                f"<h2 style='margin:0'>Total de vacancias: {total_int}</h2>"
+            )
             msg.exec()
             print(f"Vacancias totales: {total_int}")
 
@@ -610,30 +548,7 @@ class SettingsWindow(QMainWindow):
                 vfs.VacancyAnalysis()
             self.progress.setRange(0, 100)
             self.progress.setValue(100)
-
-            # Log estándar
-            log_text = buf.getvalue()
-
-            # Calcular total vacancias y añadirlo al log
-            try:
-                path = Path.cwd() / 'outputs' / 'csv' / 'results.csv'
-                if path.exists():
-                    df = pd.read_csv(path)
-                    candidates = ["predicted_vacancy", "vacancys_est", "vacancys", "predicted", "vacancy"]
-                    col = next((c for c in candidates if c in df.columns), None)
-                    if col:
-                        vals = pd.to_numeric(df[col], errors='coerce').fillna(0.0)
-                        total_int = int(np.ceil(vals.sum()))
-                        log_text += f"\n\n VACANCIES: {total_int}\n"
-                    else:
-                        log_text += "\n[INFO] No se encontró columna de vacancias en results.csv\n"
-                else:
-                    log_text += "\n[INFO] No existe outputs/csv/results.csv\n"
-            except Exception as e:
-                log_text += f"\n[ERROR] Fallo al calcular total de vacancias: {e}\n"
-
-            self.log_output.setPlainText(log_text)
-
+            self.log_output.setPlainText(buf.getvalue())
             QMessageBox.information(self, "Análisis completado", "VacancyAnalysis terminó correctamente.")
             self._refresh_csv_list()
             dump_path = Path.cwd() / 'outputs' / 'dump' / 'key_areas.dump'
@@ -650,83 +565,6 @@ class SettingsWindow(QMainWindow):
             self.log_output.setPlainText(buf.getvalue())
             QMessageBox.critical(self, "Error en análisis", "Falló VacancyAnalysis. Revisa el log.")
 
-class KeyArea3DOnlyWidget(QWidget):
-    """Viewer igual a Key Areas pero SIN tabla ni histogramas (solo navegación + 3D/2D)."""
-    def __init__(self, parent=None, pattern: str = "outputs/dump/key_area_{i}.dump"):
-        super().__init__(parent)
-        self.pattern = pattern
-
-        # --- Barra superior de navegación por key_area_i.dump ---
-        top = QWidget()
-        top_l = QHBoxLayout(top)
-        self.idx = QSpinBox()
-        self.idx.setRange(0, 1_000_000)
-        self.btn_prev = QPushButton("◀ Prev")
-        self.btn_next = QPushButton("Next ▶")
-        self.btn_load = QPushButton("Load")
-        self.path_lbl = QLineEdit()
-        self.path_lbl.setReadOnly(True)
-
-        top_l.addWidget(QLabel("key file"))
-        top_l.addWidget(self.idx)
-        top_l.addWidget(self.btn_prev)
-        top_l.addWidget(self.btn_next)
-        top_l.addWidget(self.btn_load)
-        top_l.addWidget(QLabel("Archivo:"))
-        top_l.addWidget(self.path_lbl, 1)
-
-        # --- Centro: SOLO viewer de dump (3D + 2D interno) ---
-        viewer = QWidget()
-        viewer_l = QVBoxLayout(viewer)
-        self.plotter = QtInteractor(viewer)
-        self.plotter.setMinimumHeight(600)  # para que se vea grande
-        viewer_l.addWidget(self.plotter)
-
-        # Creamos la figura 2D pero NO la agregamos al layout (no se muestra)
-        self.fig = plt.figure(figsize=(4, 4))
-        self.canvas = FigureCanvas(self.fig)  # necesario para que render_dump_to llame fig.canvas.draw()
-
-        # --- Layout raíz ---
-        root_l = QVBoxLayout(self)
-        root_l.addWidget(top)
-        root_l.addWidget(viewer, 1)
-
-        # Conexiones
-        self.btn_prev.clicked.connect(lambda: self._step(-1))
-        self.btn_next.clicked.connect(lambda: self._step(+1))
-        self.btn_load.clicked.connect(self._load_idx)
-
-        # Cargar primer índice disponible si existe
-        self._auto_seed_index()
-
-    # ----------- helpers -----------
-    def _pattern_path(self, i: int) -> str:
-        return self.pattern.format(i=i)
-
-    def _auto_seed_index(self):
-        for i in range(0, 10000):
-            if Path(self._pattern_path(i)).exists():
-                self.idx.setValue(i)
-                self._load_idx()
-                return
-        self.path_lbl.setText("(no encontrado)")
-
-    def _step(self, delta: int):
-        new_i = max(0, self.idx.value() + delta)
-        self.idx.setValue(new_i)
-        self._load_idx()
-
-    def _load_idx(self):
-        p = self._pattern_path(self.idx.value())
-        self.path_lbl.setText(p)
-        if not Path(p).exists():
-            QMessageBox.warning(self, "No existe", f"No se encontró:\n{p}")
-            return
-        try:
-            # Reutilizamos tu función de render (3D + 2D interno no visible)
-            render_dump_to(self.plotter, self.fig, p)
-        except Exception as e:
-            QMessageBox.critical(self, "Error", str(e))
 
 def main():
     app = QApplication(sys.argv)
